translate.storage.php.phpfile

Package translate :: Package storage :: Module php :: Class phpfile |
[hide private]
[frames] | no frames]

# Class phpfile

source code

This class represents a PHP file, made up of phpunits

Nested Classes | [hide private]
| UnitClass The class of units that will be instantiated and used by this class

Instance Methods | [hide private]
__init__(self, inputfile=None, encoding=`'``utf-8``'`) construct a phpfile, optionally reading in from inputfile | source code
parse(self, phpsrc) Read the source of a PHP file in and include them as units | source code
__str__(self) Convert the units back to lines. | source code
Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `detect_encoding`, `findid`, `findunit`, `findunits`, `getids`, `getprojectstyle`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setprojectstyle`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
Inherited from `base.TranslationStore`: `Extensions`, `Mimetypes`, `Name`, `sourcelanguage`, `suggestions_in_format`, `targetlanguage` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, inputfile=None, encoding=`'``utf-8``'`) (Constructor) | source code
construct a phpfile, optionally reading in from inputfile Overrides: object.__init__

### parse(self, phpsrc) | source code
Read the source of a PHP file in and include them as units Overrides: base.TranslationStore.parse

### __str__(self) (Informal representation operator) | source code
Convert the units back to lines. Overrides: object.__str__